@@ -79,7 +79,12 @@ mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot
 
   # gathering informations from vars object
 
-  y <- x$y
+  # in case original data came in different format than matrix or ts
+  if(!inherits(x$y, c("matrix", "ts"))){
+    y = as.matrix(x$y)
+  }else{
+    y <- x$y
+  }
   p <- x$p
   obs <- x$n
   k <- x$K
@@ -370,6 +375,7 @@ mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot
                  A_hat_boot_mean = A_hat_boot_mean,
                  Omodel = x,
                  boot_B = Bs,
+                 rest_mat = restriction_matrix,
                  method = 'Moving block bootstrap')
   class(result) <- 'sboot'
   return(result)
