@@ -11,21 +11,12 @@ get_restriction_matrix <- function(restriction_matrix, k){
       restriction_matrix = restriction_matrix
 
     }else if(dim(restriction_matrix)[1] == k^2 | dim(restriction_matrix)[2] == k^2){
-      if(dim(restriction_matrix)[1] == k^2){
-        restriction_matrix <- t(restriction_matrix)
-      }
-
-      twoDims <- matrix(NA, k, k)
-      for(i in 1:dim(restriction_matrix)[1]){
-        twoDims[restriction_matrix[i, ] == 1] <- 0
-      }
-      #
-      # twoDims = matrix(restriction_matrix, ncol = k)
-      # twoDims[twoDims == 0] <- NA
-      # twoDims[twoDims == 1] <- 0
-       restriction_matrix = twoDims
+      ones = matrix(rep(1,k*k),k,k)
+      restriction_matrix = c(ones) %*% restriction_matrix
+      restriction_matrix = matrix(restriction_matrix, ncol = k)
+      restriction_matrix[restriction_matrix == 1] <- NA
     }else{
-      stop(paste0("Different restriction matrix dimension than B. Please use either of the two valid formats containing kxk (", k,"x",k, ") dimensions."))
+      stop(paste0("Different restriction matrix dimension than B. Please use either of the two valid formats containing either kxk (", k,"x",k, ") or k^2xk^2 (", k^2,"x",k^2, ") dimensions."))
     }
   }else{
     restriction_matrix <- matrix(NA, k, k)
